@@ -10,20 +10,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BINDIR': '/usr/pkg/bin',
  'BINLIBDEST': '/usr/pkg/lib/python2.7',
  'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -shared -L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'BLDSHARED': 'gcc -shared -L/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-fno-strict-aliasing -O2 -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--enable-shared' '--with-dbmliborder=ndbm:bdb' '--with-system-ffi' '--with-threads' '--prefix=/usr/pkg' '--build=aarch64--netbsd' '--host=aarch64--netbsd' '--mandir=/usr/pkg/man' 'build_alias=aarch64--netbsd' 'host_alias=aarch64--netbsd' 'CC=gcc' 'CFLAGS=-O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'PKG_CONFIG=' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/.buildlink/lib/pkgconfig:/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/.buildlink/share/pkgconfig'",
+ 'CONFIG_ARGS': "'--enable-shared' '--with-dbmliborder=ndbm:bdb' '--with-system-ffi' '--with-threads' '--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' '--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' '--enable-option-checking=yes' 'build_alias=armv6--netbsdelf-eabihf' 'host_alias=armv6--netbsdelf-eabihf' 'CC=gcc' 'CFLAGS=-O2 -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'PKG_CONFIG=' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/.buildlink/lib/pkgconfig:/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python2.7',
- 'COREPYTHONPATH': ':plat-netbsd8:lib-tk:lib-old',
- 'COVERAGE_INFO': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16/coverage.info',
- 'COVERAGE_REPORT': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16/lcov-report',
+ 'COREPYTHONPATH': ':plat-netbsd9:lib-tk:lib-old',
+ 'COVERAGE_INFO': '/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include',
  'CXX': 'c++',
@@ -185,8 +185,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 1,
+ 'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
  'HAVE_LGAMMA': 1,
  'HAVE_LIBDL': 0,
@@ -356,7 +357,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'aarch64--netbsd',
+ 'HOST_GNU_TYPE': 'armv6--netbsdelf-eabihf',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include /usr/pkg/include/python2.7 /usr/pkg/include/python2.7',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -368,11 +369,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 555',
  'INSTSONAME': 'libpython2.7.so.1.0',
  'LDCXXSHARED': 'c++ -shared',
- 'LDFLAGS': '-L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDFLAGS': '-L/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LDLAST': '',
  'LDLIBRARY': 'libpython2.7.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -L/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
+ 'LDSHARED': 'gcc -shared -L/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'LIBC': '',
  'LIBDEST': '/usr/pkg/lib/python2.7',
  'LIBDIR': '/usr/pkg/lib',
@@ -385,7 +386,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBPL': '/usr/pkg/lib/python2.7/config',
  'LIBRARY': 'libpython2.7.a',
  'LIBRARY_OBJS': '\\',
- 'LIBS': '-lutil',
+ 'LIBS': '-lintl  -lutil',
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '-Wl,--export-dynamic',
@@ -394,9 +395,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LLVM_PROF_MERGER': 'true',
  'LN': '/bin/ln',
  'LOCALMODLIBS': '',
- 'MACHDEP': 'netbsd8',
- 'MACHDEPPATH': ':plat-netbsd8',
- 'MACHDEPS': 'plat-netbsd8',
+ 'MACHDEP': 'netbsd9',
+ 'MACHDEPPATH': ':plat-netbsd9',
+ 'MACHDEPS': 'plat-netbsd9',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/pkg/lib/python2.7',
  'MACH_C_THREADS': 0,
@@ -415,7 +416,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPT': '-DNDEBUG -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -432,7 +433,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
- 'PLATDIR': 'plat-netbsd8',
+ 'PLATDIR': 'plat-netbsd9',
  'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
@@ -447,12 +448,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-netbsd8:lib-tk:lib-old',
+ 'PYTHONPATH': ':plat-netbsd9:lib-tk:lib-old',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python2.7',
+ 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -fomit-frame-pointer -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -O2 -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2 -D_FORTIFY_SOURCE=2 -pthread -I/usr/include -I/usr/pkg/include -I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'unsigned short',
@@ -464,12 +465,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lutil',
+ 'SHLIBS': '-lintl  -lutil',
  'SHLIB_EXT': '".so"',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
@@ -478,21 +479,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
- 'SRCDIRS': 'Parser Objects Python Modules',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -507,7 +508,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -532,11 +533,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16',
- 'abs_srcdir': '/mnt/aarch64/pkgsrc/lang/python27/work.aarch64/Python-2.7.16',
- 'build': 'aarch64--netbsd',
+ 'abs_builddir': '/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17',
+ 'abs_srcdir': '/mnt/earmv6hf/pkgsrc/lang/python27/work.earmv6hf/Python-2.7.17',
+ 'build': 'armv6--netbsdelf-eabihf',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
- 'host': 'aarch64--netbsd',
+ 'host': 'armv6--netbsdelf-eabihf',
  'prefix': '/usr/pkg',
  'srcdir': '.'}
